@@ -75,7 +75,10 @@ make_ <- function(...) {
   args <- args[!cidx]
 
   ## Modifiers
-  wmods <- vapply(args, class, "") == "igraph_constructor_modifier"
+  ## WRONG! wmods <- vapply(args, class, "") == "igraph_constructor_modifier"
+  ## Correct:
+  wmods <- vapply(args, inherits, TRUE, what = "igraph_constructor_modifier")
+
   mods <- args[wmods]
   args <- args[!wmods]
 
@@ -506,7 +509,7 @@ with_graph_ <- function(...) {
 make_graph <- function(edges, ..., n = max(edges), isolates = NULL,
                        directed = TRUE, dir = directed, simplify = TRUE) {
 
-  if (class(edges) == "formula") {
+  if (inherits(edges, "formula")) {
     if (!missing(n)) stop("'n' should not be given for graph literals")
     if (!missing(isolates)) {
       stop("'isolates' should not be given for graph literals")
@@ -556,10 +559,9 @@ make_graph <- function(edges, ..., n = max(edges), isolates = NULL,
       }
 
       old_graph <- function(edges, n = max(edges), directed = TRUE) {
-        on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-        .Call("R_igraph_create", as.numeric(edges)-1, as.numeric(n),
-              as.logical(directed),
-              PACKAGE="igraph")
+        on.exit( .Call(C_R_igraph_finalizer) )
+        .Call(C_R_igraph_create, as.numeric(edges)-1, as.numeric(n),
+              as.logical(directed))
       }
 
       args <- list(edges, ...)
@@ -592,9 +594,8 @@ make_famous_graph <- function(name) {
 
   name <- gsub("\\s", "_", name)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_famous", as.character(name),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_famous, as.character(name))
   if (igraph_opt("add.params")) {
     res$name <- capitalize(name)
   }
@@ -654,10 +655,9 @@ make_empty_graph <- function(n=0, directed=TRUE) {
   n <- as.integer(n)
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_empty", n, directed,
-        PACKAGE="igraph")
+  res <- .Call(C_R_igraph_empty, n, directed)
 
   res
 }
@@ -920,10 +920,9 @@ make_star <- function(n, mode=c("in", "out", "mutual", "undirected"),
   mode <- igraph.match.arg(mode)
   mode1 <- switch(mode, "out"=0, "in"=1, "undirected"=2, "mutual"=3)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_star", as.numeric(n), as.numeric(mode1),
-               as.numeric(center)-1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_star, as.numeric(n), as.numeric(mode1),
+               as.numeric(center)-1)
   if (igraph_opt("add.params")) {
     res$name <- switch(mode, "in"="In-star", "out"="Out-star", "Star")
     res$mode <- mode
@@ -953,13 +952,12 @@ star <- function(...) constructor_spec(make_star, ...)
 #' @export
 #' @examples
 #' make_full_graph(5)
-#' str(make_full_graph(4, directed = TRUE))
+#' print_all(make_full_graph(4, directed = TRUE))
 
 make_full_graph <- function(n, directed=FALSE, loops=FALSE) {
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_full", as.numeric(n), as.logical(directed),
-               as.logical(loops),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_full, as.numeric(n), as.logical(directed),
+               as.logical(loops))
   if (igraph_opt("add.params")) {
     res$name <- "Full graph"
     res$loops <- loops
@@ -1013,11 +1011,10 @@ make_lattice <- function(dimvector = NULL, length = NULL, dim = NULL,
     dimvector <- rep(length, dim)
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_lattice", as.numeric(dimvector), as.numeric(nei),
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_lattice, as.numeric(dimvector), as.numeric(nei),
                as.logical(directed), as.logical(mutual),
-               as.logical(circular),
-               PACKAGE="igraph")
+               as.logical(circular))
   if (igraph_opt("add.params")) {
     res$name <- "Lattice graph"
     res$dimvector <- dimvector
@@ -1054,14 +1051,13 @@ lattice <- function(...) constructor_spec(make_lattice, ...)
 #' @family determimistic constructors
 #' @export
 #' @examples
-#' str(make_ring(10))
-#' str(make_ring(10, directed = TRUE, mutual = TRUE))
+#' print_all(make_ring(10))
+#' print_all(make_ring(10, directed = TRUE, mutual = TRUE))
 
 make_ring <- function(n, directed=FALSE, mutual=FALSE, circular=TRUE) {
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_ring", as.numeric(n), as.logical(directed),
-               as.logical(mutual), as.logical(circular),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_ring, as.numeric(n), as.logical(directed),
+               as.logical(mutual), as.logical(circular))
   if (igraph_opt("add.params")) {
     res$name <- "Ring graph"
     res$mutual <- mutual
@@ -1105,10 +1101,9 @@ make_tree <- function(n, children=2, mode=c("out", "in", "undirected")) {
   mode <- igraph.match.arg(mode)
   mode1 <- switch(mode, "out"=0, "in"=1, "undirected"=2);
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_tree", as.numeric(n), as.numeric(children),
-               as.numeric(mode1),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_tree, as.numeric(n), as.numeric(children),
+               as.numeric(mode1))
   if (igraph_opt("add.params")) {
     res$name <- "Tree"
     res$children <- children
@@ -1157,9 +1152,8 @@ tree <- function(...) constructor_spec(make_tree, ...)
 
 graph_from_atlas <- function(n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_atlas", as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_atlas, as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("Graph from the Atlas #%i", n)
     res$n <- n
@@ -1168,7 +1162,7 @@ graph_from_atlas <- function(n) {
 }
 
 #' @rdname graph_from_atlas
-#'  @param ... Passed to \code{graph_from_atlas}.
+#' @param ... Passed to \code{graph_from_atlas}.
 #' @export
 
 atlas <- function(...) constructor_spec(graph_from_atlas, ...)
@@ -1203,10 +1197,9 @@ atlas <- function(...) constructor_spec(graph_from_atlas, ...)
 
 make_chordal_ring <- function(n, w) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_extended_chordal_ring", as.numeric(n),
-               as.matrix(w),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_extended_chordal_ring, as.numeric(n),
+               as.matrix(w))
   if (igraph_opt("add.params")) {
     res$name <- "Extended chordal ring"
     res$w <- w
@@ -1257,9 +1250,8 @@ make_line_graph <- function(graph) {
     stop("Not a graph object")
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_line_graph", graph,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_line_graph, graph)
   if (igraph_opt("add.params")) {
     res$name <- "Line graph"
   }
@@ -1309,9 +1301,8 @@ line_graph <- function(...) constructor_spec(make_line_graph, ...)
 
 make_de_bruijn_graph <- function(m, n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_de_bruijn", as.numeric(m), as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_de_bruijn, as.numeric(m), as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("De-Bruijn graph %i-%i", m, n)
     res$m <- m
@@ -1358,9 +1349,8 @@ de_bruijn_graph <- function(...) constructor_spec(make_de_bruijn_graph, ...)
 #'
 make_kautz_graph <- function(m, n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_kautz", as.numeric(m), as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_kautz, as.numeric(m), as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("Kautz graph %i-%i", m, n)
     res$m <- m
@@ -1414,9 +1404,8 @@ make_full_bipartite_graph <- function(n1, n2, directed=FALSE,
   directed <- as.logical(directed)
   mode1 <- switch(igraph.match.arg(mode), "out"=1, "in"=2, "all"=3, "total"=3)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_full_bipartite", n1, n2, as.logical(directed), mode1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_full_bipartite, n1, n2, as.logical(directed), mode1)
   if (igraph_opt("add.params")) {
     res$graph$name <- "Full bipartite graph"
     res$n1 <- n1
@@ -1480,9 +1469,8 @@ make_bipartite_graph <- function(types, edges, directed=FALSE) {
   edges <- as.numeric(edges)-1
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_create_bipartite", types, edges, directed,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_create_bipartite, types, edges, directed)
   set_vertex_attr(res, "type", value=types)
 }
 
@@ -1508,17 +1496,16 @@ bipartite_graph <- function(...) constructor_spec(make_bipartite_graph, ...)
 #' @family determimistic constructors
 #' @export
 #' @examples
-#' str(make_full_citation_graph(10))
+#' print_all(make_full_citation_graph(10))
 
 make_full_citation_graph <- function(n, directed=TRUE) {
   # Argument checks
   n <- as.integer(n)
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_full_citation", n, directed,
-        PACKAGE="igraph")
+  res <- .Call(C_R_igraph_full_citation, n, directed)
 
   res <- set_graph_attr(res, 'name', 'Full citation graph')
   res
